'use client';
import { jsx, jsxs } from 'react/jsx-runtime';
import { DeleteOutline } from '@mui/icons-material';
import { Stack, Avatar, Box, Typography } from '@mui/material';
import '@mui/material/Button';
import '@mui/material/CircularProgress';
import 'react';
import { I as IconButton } from './IconButton-client-RgaMe93C.mjs';

/**
 * format file size to human readable string
 *
 * it will convert bytes to KB, MB, GB, TB, PB, EB, ZB, YB
 *
 * @param bytes file size in bytes
 * @param decimals number of decimal places
 *
 * @example
 *
 * ```js
 * formatBytes(0) // 0 Bytes
 * formatBytes(1024) // 1 KB
 * formatBytes(1024, 2) // 1.00 KB
 * formatBytes(1024 * 1024) // 1 MB
 * ```
 */ const formatBytes = (bytes, decimals = 0)=>{
    if (bytes === 0) return '0 Bytes';
    const k = 1024;
    const dm = decimals || 2;
    const sizes = [
        'Bytes',
        'KB',
        'MB',
        'GB',
        'TB',
        'PB',
        'EB',
        'ZB',
        'YB'
    ];
    const i = Math.floor(Math.log(bytes) / Math.log(k));
    return `${parseFloat((bytes / k ** i).toFixed(dm))} ${sizes[i]}`;
};
/**
 * validate file type by MIME type
 *
 * @param file the file to validate
 * @param accepts the accepted file MIME types
 *
 * @example
 *
 * ```js
 * validateFileType({ type: 'image/png' }, ['image/png', 'image/jpeg']) // true
 * validateFileType({ type: 'image/png' }, ['image/jpeg']) // false
 * validateFileType({ type: 'image/png' }, ['image/*']) // true
 * ```
 */ const validateFileType = (file, accepts)=>{
    if (accepts.length === 0) return true;
    // 獲取文件的MIME類型
    const fileMimeType = file.type;
    return accepts.some((accept)=>{
        if (accept === fileMimeType) {
            return true;
        }
        if (accept.endsWith('/*')) {
            const acceptedCategory = accept.split('/')[0];
            const fileCategory = fileMimeType.split('/')[0];
            if (acceptedCategory === fileCategory) {
                return true;
            }
        }
        return false;
    });
};

const FileList = ({ files, handleDeleteFile })=>/*#__PURE__*/ jsx(Stack, {
        spacing: 1,
        children: files.map((file)=>/*#__PURE__*/ jsxs(Stack, {
                spacing: 1,
                direction: "row",
                justifyContent: "space-between",
                alignItems: "center",
                sx: {
                    '&:hover': {
                        borderRadius: 2,
                        backgroundColor: 'grey.100'
                    },
                    p: 1
                },
                children: [
                    /*#__PURE__*/ jsx(Avatar, {
                        sx: {
                            fontSize: '0.75rem',
                            bgcolor: 'inherit',
                            color: 'primary.main',
                            border: 1,
                            borderColor: 'primary.main'
                        },
                        children: file.file.name.split('.').pop()?.toLocaleUpperCase()
                    }),
                    /*#__PURE__*/ jsxs(Box, {
                        sx: {
                            overflow: 'hidden',
                            width: '100%'
                        },
                        children: [
                            /*#__PURE__*/ jsx(Typography, {
                                fontWeight: "bold",
                                sx: {
                                    overflow: 'hidden',
                                    textOverflow: 'ellipsis',
                                    whiteSpace: 'nowrap'
                                },
                                children: file.file.name
                            }),
                            /*#__PURE__*/ jsx(Typography, {
                                fontSize: "0.75rem",
                                color: "text.secondary",
                                children: formatBytes(file.file.size)
                            })
                        ]
                    }),
                    /*#__PURE__*/ jsx(IconButton, {
                        size: "small",
                        onClick: ()=>handleDeleteFile(file.id),
                        children: /*#__PURE__*/ jsx(DeleteOutline, {})
                    })
                ]
            }, file.id))
    });

export { FileList as F, validateFileType as v };
